Refugee Camp Security: Decreasing Vulnerability Through Demographic Controls | Journal of Refugee Studies | Oxford Academic
Description: Abstract. In the past, refugee camp security has been examined in many lights; however, the demographic make-up of camps has not been focused on. In this artic

Skip to Main Content

# Refugee Camp Security: Decreasing Vulnerability Through Demographic Controls

Richard A. I. Johnson
Department of Political Science, University of California, Davis, One Shields Avenue, Davis, CA 95616
Search for other works by this author on:
Oxford Academic
Google Scholar
Richard A. I. Johnson
Journal of Refugee Studies, Volume 24, Issue 1, March 2011, Pages 23–46, https://doi.org/10.1093/jrs/feq048
Published:
21 January 2011
Article history
Received:
01 October 2009
Revision received:
01 August 2010
Published:
21 January 2011

## Abstract

In the past, refugee camp security has been examined in many lights; however, the demographic make-up of camps has not been focused on. In this article, I present a quantitative model that examines attacks on refugee camps. I argue that the likelihood of an attack on a camp is affected by the demographic make-up of the camp. The primary demographic causes that affect vulnerability are the level of male population of the camp, age of camp residents, and the size of the camp. With the available data, I find that these demographic indicators are significant in determining the likelihood of an attack. Assessing what characteristics of camps and their populations increase the likelihood of an attack should serve as a guide to the implementation and organization of new refugee camps to ensure peace and stability for an already fragile community.

© The Author 2011. Published by Oxford University Press. All rights reserved. For Permissions, please email: journals.permissions@oup.com
Issue Section:
Articles
You do not currently have access to this article.
Download all figures

## Sign in

Don't already have an Oxford Academic account? Register
You could not be signed in. Please check your email address / username and password and try again.

### Oxford Academic account

Email address / Username
?
Password
Forgot password?
Don't have an account?
HPC

#### Email address / username

Most users should sign in with their email address. If you originally registered with a username please use that to sign in.

Close

### Sign in via your Institution

Sign in

## Purchase

Subscription prices and ordering

### Short-term Access

To purchase short term access, please sign in to your Oxford Academic account above.

Don't already have an Oxford Academic account? Register

Refugee Camp Security: Decreasing Vulnerability Through Demographic Controls - 24 Hours access
EUR €37.00
GBP £29.00
USD $47.00

### Rental

This article is also available for rental through DeepDyve.
Close

##### This Feature Is Available To Subscribers Only

Sign In or Create an Account

Close

This PDF is available to Subscribers Only

View Article Abstract & Purchase Options

For full access to this pdf, sign in to an existing account, or purchase an annual subscription.

Close